(function() {
  var Express, Path, app, fullOutputHosts;
  Path = require("path");
  Express = require("express");
  app = Express.createServer();
  fullOutputHosts = ['127.0.0.1'];
  if (process.env.JINKIES_OUTPUT_WHITELIST) {
    process.env.JINKIES_OUTPUT_WHITELIST.split(",").forEach(function(ip) {
      return fullOutputHosts.push(ip);
    });
  }
  app.configure(function() {
    app.use(Express.logger());
    app.use(Express.methodOverride());
    app.use(Express.bodyDecoder());
    return app.use(Express.errorHandler({
      showStack: true,
      dumpExceptions: true
    }));
  });
  app.post("/", function(req, res) {
    var branch, info, job, owner, project;
    info = JSON.parse(req.body.payload);
    owner = info.repository.owner.name;
    branch = info["ref"].split("/")[2];
    project = "" + owner + "-" + info.repository.name;
    job = app.jinkies.job_for(project);
    return job.triggerBuild(branch, req.body.payload, function(err, data) {
      return res.send(data, {
        "Content-Type": "Content-Type",
        "application/json": "application/json"
      }, 200);
    });
  });
  app.get("/jobs", function(req, res) {
    return app.jinkies.jobs(function(err, jobs) {
      return res.send(jobs, {
        "Content-Type": "Content-Type",
        "application/json": "application/json"
      }, 200);
    });
  });
  app.get("/jobs/:job", function(req, res) {
    var job;
    job = app.jinkies.job_for(req.params.job);
    return job.info(function(err, info) {
      return res.send(info, {
        "Content-Type": "Content-Type",
        "application/json": "application/json"
      }, 200);
    });
  });
  app.post("/jobs/:job/builds", function(req, res) {
    var branch_name, job;
    job = app.jinkies.job_for(req.params.job);
    branch_name = req.body.branch || "master";
    return job.triggerBuild(branch_name, "{}", function(err, data) {
      return res.send(data, {
        "Content-Type": "Content-Type",
        "application/json": "application/json"
      }, 200);
    });
  });
  app.get("/jobs/:job/builds/:build", function(req, res) {
    var job;
    job = app.jinkies.job_for(req.params.job);
    return job.build_for(req.params.build, function(err, build) {
      return build.consoleText(function(err, data) {
        var friendlyRequest, ip;
        friendlyRequest = (function() {
          var _i, _len, _results;
          _results = [];
          for (_i = 0, _len = fullOutputHosts.length; _i < _len; _i++) {
            ip = fullOutputHosts[_i];
            if (ip === req.socket.remoteAddress) {
              _results.push(ip);
            }
          }
          return _results;
        })();
        if (friendlyRequest.length > 0) {
          build.consoleText = data;
        }
        return res.send(build, {
          "Content-Type": "Content-Type",
          "application/json": "application/json"
        }, 200);
      });
    });
  });
  app.get("/jobs/:job/branches/:branch", function(req, res) {
    var job;
    job = app.jinkies.job_for(req.params.job);
    return job.branches_for(req.params.branch, function(err, branches) {
      return res.send(branches, {
        "Content-Type": "Content-Type",
        "application/json": "application/json"
      }, 200);
    });
  });
  exports.App = app;
}).call(this);
