(function() {
  var Build, BuildRequest, HttpRequest, Job, Map;
  Map = require("async").map;
  Build = require("jenkins/build").Build;
  HttpRequest = require("jenkins/utils/http_request").HttpRequest;
  BuildRequest = require("jenkins/utils/job_build_request").JobBuildRequest;
  Job = (function() {
    function Job(host, name) {
      this.host = host;
      this.name = name;
      this.client = new HttpRequest(this.host);
    }
    Job.prototype.info = function(callback) {
      return this.client.fetch("/job/" + this.name + "/api/json", function(err, data) {
        return callback(err, data);
      });
    };
    Job.prototype.builds = function(callback) {
      var self;
      self = this;
      return this.info(function(err, data) {
        var build_for, hash, numbers;
        numbers = (function() {
          var _i, _len, _ref, _results;
          _ref = data.builds;
          _results = [];
          for (_i = 0, _len = _ref.length; _i < _len; _i++) {
            hash = _ref[_i];
            _results.push(hash.number);
          }
          return _results;
        })();
        build_for = self.build_for.bind(self);
        return Map(numbers, build_for, function(err, results) {
          return callback(err, results);
        });
      });
    };
    Job.prototype.status = function(callback) {
      return this.branches_for('master', function(err, branches) {
        var branch;
        branch = branches[0] || {
          status: 'failed'
        };
        return callback(err, branch.status);
      });
    };
    Job.prototype.build_for = function(number, callback) {
      var host, name;
      host = this.host;
      name = this.name;
      return this.client.fetch("/job/" + this.name + "/" + number + "/api/json", function(err, data) {
        var build;
        build = new Build(host, name, number, data);
        return callback(err, build);
      });
    };
    Job.prototype.branches_for = function(branch, callback) {
      var self;
      self = this;
      return this.builds(function(err, data) {
        var hash, results;
        results = (function() {
          var _i, _len, _results;
          _results = [];
          for (_i = 0, _len = data.length; _i < _len; _i++) {
            hash = data[_i];
            if (hash.branch === branch) {
              _results.push(hash);
            }
          }
          return _results;
        })();
        return callback(err, results.slice(0, 11));
      });
    };
    Job.prototype.triggerBuild = function(branch, payload, callback) {
      var req;
      req = new BuildRequest(this.client.url, this.name, branch, payload);
      return req.trigger(function(err, data) {
        return callback(err, data);
      });
    };
    return Job;
  })();
  exports.Job = Job;
}).call(this);
