(function() {
  var Campfire, HTTP;
  HTTP = require("http");
  Campfire = (function() {
    function Campfire(options) {
      this.token = options.token;
      this.account = options.account;
      this.domain = this.account + ".campfirenow.com";
      this.authorization = "Basic " + new Buffer("" + this.token + ":x").toString('base64');
    }
    Campfire.prototype.Rooms = function(callback) {
      return this.get("/rooms", callback);
    };
    Campfire.prototype.User = function(id, callback) {
      return this.get("/users/" + id, callback);
    };
    Campfire.prototype.Me = function(callback) {
      return this.get("/users/me", callback);
    };
    Campfire.prototype.Room = function(id) {
      var self;
      self = this;
      return {
        show: function(callback) {
          return self.post("/room/" + id, "", callback);
        },
        join: function(callback) {
          return self.post("/room/" + id + "/join", "", callback);
        },
        leave: function(callback) {
          return self.post("/room/" + id + "/leave", "", callback);
        },
        lock: function(callback) {
          return self.post("/room/" + id + "/lock", "", callback);
        },
        unlock: function(callback) {
          return self.post("/room/" + id + "/unlock", "", callback);
        },
        paste: function(text, callback) {
          return this.message(text, "PasteMessage", callback);
        },
        sound: function(text, callback) {
          return this.message(text, "SoundMessage", callback);
        },
        speak: function(text, callback) {
          return this.message(text, "TextMessage", callback);
        },
        message: function(text, type, callback) {
          var body;
          body = {
            message: {
              'body': text,
              'type': type
            }
          };
          return self.post("/room/" + id + "/speak", body, callback);
        },
        listen: function(callback) {
          var client, headers, path, request;
          path = "/room/" + id + "/live.json";
          headers = {
            "Host": "streaming.campfirenow.com",
            "Authorization": self.authorization
          };
          client = HTTP.createClient(443, "streaming.campfirenow.com", true);
          request = client.request("GET", path, headers);
          request.on("response", function(response) {
            response.setEncoding("utf8");
            return response.on("data", function(chunk) {
              var data, _i, _len, _ref, _results;
              if (chunk !== " ") {
                _ref = chunk.split("\r");
                _results = [];
                for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                  data = _ref[_i];
                  if (data !== "") {
                    _results.push((function(data) {
                      return callback(null, JSON.parse(data));
                    })(data));
                  }
                }
                return _results;
              }
            });
          });
          return request.end();
        }
      };
    };
    Campfire.prototype.get = function(path, callback) {
      return this.request("GET", path, null, callback);
    };
    Campfire.prototype.post = function(path, body, callback) {
      return this.request("POST", path, body, callback);
    };
    Campfire.prototype.request = function(method, path, body, callback) {
      var client, headers, request;
      headers = {
        "Authorization": this.authorization,
        "Host": this.domain,
        "Content-Type": "application/json"
      };
      if (method === "POST") {
        if (typeof body !== "string") {
          body = JSON.stringify(body);
        }
        headers["Content-Length"] = body.length;
      }
      client = HTTP.createClient(443, this.domain, true);
      request = client.request(method, path, headers);
      request.on("response", function(response) {
        var data;
        data = "";
        response.on("data", function(chunk) {
          return data += chunk;
        });
        response.on("end", function() {
          try {
            return callback(null, JSON.parse(data));
          } catch (err) {
            return callback(null, {});
          }
        });
        return response.on('error', function(err) {
          return callback(err, {});
        });
      });
      if (method === "POST") {
        request.write(body);
      }
      return request.end();
    };
    return Campfire;
  })();
  exports.Campfire = Campfire;
}).call(this);
